@@ -54,6 +54,6 @@ def PrepareResourceToUpload(command):
         if len(bucket_key) > 0:
             res_info['cos_path'] = bucket_key
         else:
-            print('err: upload resource file failed')
+            print('err: upload resource file failed', flush=True)
             sys.exit(-1)
     return command
\ No newline at end of file
