@@ -13,7 +13,14 @@ kOptionUploadFiles = '--cli-upload-files'
 kOptionSetConfigFile = '--set-config-file'
 
 kCmdHelp = 'help'
-kCmdsUpdateCfg = ['set-title-region', 'set-secret-key', 'set-title-id', 'set-env']
+kCmdsUpdateCfg = [
+    'set-title-id',
+    'set-secret-key',
+    'set-title-region',
+    'set-env',
+    'set-verify-type', # SecretKey, UserAccount
+    'set-portal-user',
+    'set-portal-pwd']
 
 kCmdsConfigs = ['configs', 'config', 'configuration', 'cfg']
 kGlobalHostCommands = ['help', 'list-cloud-resource-regions'] 
@@ -57,8 +64,8 @@ def InitCmdline():
     global gCmdline
     global gVerboseLog
     gCmdline = sys.argv
-    print("------")
-    print(">> Original cmd: [" + " ".join(gCmdline) + "]")
+    print("------", flush=True)
+    print(">> Original cmd: [" + " ".join(gCmdline) + "]", flush=True)
     for word in kVerboseWords:
         if word in gCmdline:
             gVerboseLog = True
@@ -69,7 +76,7 @@ def InitCmdline():
         pgos_cli_config.SetCustomCfgFile(gCmdline[config_file_idx + 1])
         del gCmdline[config_file_idx + 1]
         del gCmdline[config_file_idx]
-    print(">> Pruned cmd: [" + " ".join(gCmdline) + "]")
+    print(">> Pruned cmd: [" + " ".join(gCmdline) + "]", flush=True)
 
 
 def GetApiProtocol():
@@ -156,32 +163,32 @@ def IsOption(str):
     return str.startswith(u'--')
 
 def ParseCliJsonString(data_res):
-    print("------")
+    print("------", flush=True)
     json_params = {}
     done = False
     try:
         json_params = json.loads(s = data_res)
         done = True
     except Exception as e:
-        print(u'warnning: parsing ' + data_res + u' as JSON string failed: ' + str(e.args))
+        print(u'warnning: parsing ' + data_res + u' as JSON string failed: ' + str(e.args), flush=True)
     
     if done:
         return json_params
     
     root_dir = sys.path[0]
     joined_dir = os.path.normpath(os.path.join(root_dir, data_res))
-    print(f'root dir:{root_dir}, json file dir:{joined_dir}')
+    print(f'root dir:{root_dir}, json file dir:{joined_dir}', flush=True)
     
     try:
         f_content = open(joined_dir, encoding="utf-8").read()
-        print(u'try: parsing ' + joined_dir + u' as local JSON file')
+        print(u'try: parsing ' + joined_dir + u' as local JSON file', flush=True)
         json_params = json.loads(s = f_content)
         done = True
     except Exception as e:
-        print( u'warnning: parsing ' + joined_dir + ' as JSON file failed: ' + str(e.args))
+        print( u'warnning: parsing ' + joined_dir + ' as JSON file failed: ' + str(e.args), flush=True)
 
     if not done:
-        print(u'err: when parsing data for ' + data_res )
+        print(u'err: when parsing data for ' + data_res, flush=True)
         os._exit(-1)
 
     return json_params
@@ -194,12 +201,12 @@ def MergeCommandParams(command):
             params.update(option.data)
         if option.option == kOptionUploadFiles:
             if not isinstance(option.data, list):
-                print('!!!! Oops, upload files params format error')
+                print('!!!! Oops, upload files params format error', flush=True)
                 sys.exit(-1)
             for file_info in option.data:
                 if not u'label' in file_info or not u'cos_path' in file_info:
                     # todo print error, abstruct 'function:FatalError()'
-                    print('!!!! Oops, missing key of file_info of upload files')
+                    print('!!!! Oops, missing key of file_info of upload files', flush=True)
                     sys.exit(-1)
                 params[ file_info['label'] ] = file_info[u'cos_path']
     return params
\ No newline at end of file
